@@ -3,6 +3,7 @@
  * from the sidepanel
  *
  * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +40,6 @@
 #include "pluma-file-browser-view.h"
 #include "pluma-file-browser-store.h"
 #include "pluma-file-bookmarks-store.h"
-#include "pluma-file-browser-marshal.h"
 #include "pluma-file-browser-enum-types.h"
 
 #define XML_UI_FILE "pluma-file-browser-widget-ui.xml"
@@ -343,8 +343,7 @@ pluma_file_browser_widget_finalize (GObject * object)
 	g_object_unref (obj->priv->bookmarks_store);
 	g_object_unref (obj->priv->combo_model);
 
-	g_slist_foreach (obj->priv->filter_funcs, (GFunc) g_free, NULL);
-	g_slist_free (obj->priv->filter_funcs);
+	g_slist_free_full (obj->priv->filter_funcs, g_free);
 
 	for (loc = obj->priv->locations; loc; loc = loc->next)
 		location_free ((Location *) (loc->data));
@@ -436,26 +435,22 @@ pluma_file_browser_widget_class_init (PlumaFileBrowserWidgetClass * klass)
 	    g_signal_new ("uri-activated",
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass,
-					   uri_activated), NULL, NULL,
-			  g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
+			  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass, uri_activated),
+			  NULL, NULL, NULL,
+			  G_TYPE_NONE, 1,
 			  G_TYPE_STRING);
 	signals[ERROR] =
 	    g_signal_new ("error", G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass,
-					   error), NULL, NULL,
-			  pluma_file_browser_marshal_VOID__UINT_STRING,
+			  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass, error),
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_STRING);
 
 	signals[CONFIRM_DELETE] =
 	    g_signal_new ("confirm-delete", G_OBJECT_CLASS_TYPE (object_class),
 	                  G_SIGNAL_RUN_LAST,
-	                  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass,
-	                                   confirm_delete),
-	                  g_signal_accumulator_true_handled,
-	                  NULL,
-	                  pluma_file_browser_marshal_BOOLEAN__OBJECT_POINTER,
+	                  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass, confirm_delete),
+	                  g_signal_accumulator_true_handled, NULL, NULL,
 	                  G_TYPE_BOOLEAN,
 	                  2,
 	                  G_TYPE_OBJECT,
@@ -464,11 +459,8 @@ pluma_file_browser_widget_class_init (PlumaFileBrowserWidgetClass * klass)
 	signals[CONFIRM_NO_TRASH] =
 	    g_signal_new ("confirm-no-trash", G_OBJECT_CLASS_TYPE (object_class),
 	                  G_SIGNAL_RUN_LAST,
-	                  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass,
-	                                   confirm_no_trash),
-	                  g_signal_accumulator_true_handled,
-	                  NULL,
-	                  pluma_file_browser_marshal_BOOLEAN__POINTER,
+	                  G_STRUCT_OFFSET (PlumaFileBrowserWidgetClass, confirm_no_trash),
+	                  g_signal_accumulator_true_handled, NULL, NULL,
 	                  G_TYPE_BOOLEAN,
 	                  1,
 	                  G_TYPE_POINTER);
@@ -790,7 +782,7 @@ create_combo (PlumaFileBrowserWidget * obj)
 
 static GtkActionEntry toplevel_actions[] =
 {
-	{"FilterMenuAction", NULL, N_("_Filter")}
+	{"FilterMenuAction", NULL, N_("_Filter"), NULL, NULL, NULL}
 };
 
 static const GtkActionEntry tree_actions_selection[] =
@@ -1334,8 +1326,7 @@ pluma_file_browser_widget_get_first_selected (PlumaFileBrowserWidget *obj,
 
 	result = gtk_tree_model_get_iter(model, iter, (GtkTreePath *)(rows->data));
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return result;
 }
@@ -1457,8 +1448,7 @@ get_deletable_files (PlumaFileBrowserWidget *obj) {
 		paths = g_list_append (paths, gtk_tree_path_copy (path));
 	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return paths;
 }
@@ -1491,8 +1481,7 @@ delete_selected_files (PlumaFileBrowserWidget * obj, gboolean trash)
 	result = pluma_file_browser_store_delete_all (PLUMA_FILE_BROWSER_STORE (model),
 						      rows, trash);
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return result == PLUMA_FILE_BROWSER_STORE_RESULT_OK;
 }
@@ -1526,39 +1515,57 @@ get_topmost_file (GFile * file)
 }
 
 static GtkWidget *
-create_goto_menu_item (PlumaFileBrowserWidget * obj, GList * item,
-		       GdkPixbuf * icon)
+create_goto_menu_item (PlumaFileBrowserWidget *obj,
+                       GList                  *item,
+                       GdkPixbuf              *icon_pixbuf)
 {
-	GtkWidget *result;
-	gchar *unescape;
+	GtkWidget *menu_item;
+	gchar     *label_text;
 	GdkPixbuf *pixbuf = NULL;
-	Location *loc;
+	Location  *loc;
 
 	loc = (Location *) (item->data);
 
-	if (!get_from_bookmark_file (obj, loc->virtual_root, &unescape, &pixbuf)) {
-		unescape = pluma_file_browser_utils_file_basename (loc->virtual_root);
+	if (!get_from_bookmark_file (obj, loc->virtual_root, &label_text, &pixbuf)) {
+		label_text = pluma_file_browser_utils_file_basename (loc->virtual_root);
 
-		if (icon)
-			pixbuf = g_object_ref (icon);
+		if (icon_pixbuf)
+			pixbuf = g_object_ref (icon_pixbuf);
 	}
 
 	if (pixbuf) {
-		result = pluma_image_menu_item_new_from_pixbuf (pixbuf, unescape);
+		/* code based on https://developer.gnome.org/gtk3/stable/GtkImageMenuItem.html */
+		GtkWidget *box;
+		GtkWidget *icon;
+		GtkWidget *label;
+
+		box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+
+		icon = gtk_image_new_from_pixbuf (pixbuf);
+
+		label = gtk_label_new (NULL);
+		gtk_label_set_text (GTK_LABEL (label), label_text);
+		gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+
+		menu_item = gtk_menu_item_new ();
+		gtk_container_add (GTK_CONTAINER (box), icon);
+		gtk_container_add (GTK_CONTAINER (box), label);
+		gtk_container_add (GTK_CONTAINER (menu_item), box);
+
 		g_object_unref (pixbuf);
 	} else {
-		result = gtk_menu_item_new_with_label (unescape);
+		menu_item = gtk_menu_item_new_with_label (label_text);
 	}
 
-	g_object_set_data (G_OBJECT (result), LOCATION_DATA_KEY, item);
-	g_signal_connect (result, "activate",
-			  G_CALLBACK (on_location_jump_activate), obj);
+	g_object_set_data (G_OBJECT (menu_item), LOCATION_DATA_KEY, item);
+	g_signal_connect (menu_item, "activate",
+	                  G_CALLBACK (on_location_jump_activate), obj);
 
-	gtk_widget_show (result);
+	gtk_widget_show_all (menu_item);
 
-	g_free (unescape);
+	g_free (label_text);
 
-	return result;
+	return menu_item;
 }
 
 static GList *
@@ -2055,8 +2062,7 @@ pluma_file_browser_widget_get_num_selected_files_or_directories (PlumaFileBrowse
 		}
 	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return result;
 }
@@ -2179,8 +2185,7 @@ try_activate_drive (PlumaFileBrowserWidget *widget,
 		try_mount_volume (widget, volume);
 	}
 
-	g_list_foreach (volumes, (GFunc)g_object_unref, NULL);
-	g_list_free (volumes);
+	g_list_free_full (volumes, g_object_unref);
 }
 
 static void
@@ -2473,8 +2478,7 @@ directory_open (PlumaFileBrowserWidget *obj,
 				       PLUMA_FILE_BROWSER_ERROR_OPEN_DIRECTORY,
 				       error->message);
 
-			g_error_free (error);
-			error = NULL;
+			g_clear_error (&error);
 		}
 	}
 
