@@ -4,6 +4,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2002 Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +37,6 @@
 #include <gtk/gtk.h>
 #include <pluma/pluma-utils.h>
 #include "pluma-spell-checker-dialog.h"
-#include "pluma-spell-marshal.h"
 
 struct _PlumaSpellCheckerDialog
 {
@@ -142,8 +142,7 @@ pluma_spell_checker_dialog_class_init (PlumaSpellCheckerDialogClass * klass)
  			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaSpellCheckerDialogClass, ignore),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_STRING);
@@ -153,8 +152,7 @@ pluma_spell_checker_dialog_class_init (PlumaSpellCheckerDialogClass * klass)
  			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaSpellCheckerDialogClass, ignore_all),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_STRING);
@@ -164,8 +162,7 @@ pluma_spell_checker_dialog_class_init (PlumaSpellCheckerDialogClass * klass)
  			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaSpellCheckerDialogClass, change),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING_STRING,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_STRING,
@@ -176,8 +173,7 @@ pluma_spell_checker_dialog_class_init (PlumaSpellCheckerDialogClass * klass)
  			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaSpellCheckerDialogClass, change_all),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING_STRING,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_STRING,
@@ -188,8 +184,7 @@ pluma_spell_checker_dialog_class_init (PlumaSpellCheckerDialogClass * klass)
  			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaSpellCheckerDialogClass, add_word_to_personal),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_STRING);
@@ -426,8 +421,7 @@ pluma_spell_checker_dialog_set_misspelled_word (PlumaSpellCheckerDialog *dlg,
 	update_suggestions_list_model (dlg, sug);
 
 	/* free the suggestion list */
-	g_slist_foreach (sug, (GFunc)g_free, NULL);
-	g_slist_free (sug);
+	g_slist_free_full (sug, g_free);
 
 	gtk_widget_set_sensitive (dlg->ignore_button, TRUE);
 	gtk_widget_set_sensitive (dlg->ignore_all_button, TRUE);
@@ -578,8 +572,7 @@ check_word_button_clicked_handler (GtkButton *button, PlumaSpellCheckerDialog *d
 		update_suggestions_list_model (dlg, sug);
 
 		/* free the suggestion list */
-		g_slist_foreach (sug, (GFunc)g_free, NULL);
-		g_slist_free (sug);
+		g_slist_free_full (sug, g_free);
 	}
 }
 
