@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,18 +43,20 @@
 #include "pluma-print-preview.h"
 #include "pluma-progress-message-area.h"
 #include "pluma-debug.h"
-#include "pluma-prefs-manager-app.h"
-#include "pluma-prefs-manager-private.h"
 #include "pluma-enum-types.h"
+#include "pluma-settings.h"
 
 #define PLUMA_TAB_KEY "PLUMA_TAB_KEY"
 
 struct _PlumaTabPrivate
 {
+	GSettings	       *editor_settings;
 	PlumaTabState	        state;
 
+	GtkWidget	       *overlay;
 	GtkWidget	       *view;
 	GtkWidget	       *view_scrolled_window;
+	GtkWidget	       *view_map_frame;
 
 	GtkWidget	       *message_area;
 	GtkWidget	       *print_preview;
@@ -240,6 +243,10 @@ pluma_tab_finalize (GObject *object)
 		tab->priv->idle_scroll = 0;
 	}
 
+	/* settings must be cleared in finalize and not in dispose to prevent
+	a warning when trying to close pluma while print-preview is active */
+	g_clear_object (&tab->priv->editor_settings);
+
 	G_OBJECT_CLASS (pluma_tab_parent_class)->finalize (object);
 }
 
@@ -364,6 +371,10 @@ set_view_properties_according_to_state (PlumaTab      *tab,
 					PlumaTabState  state)
 {
 	gboolean val;
+	gboolean hl_current_line;
+
+	hl_current_line = g_settings_get_boolean (tab->priv->editor_settings,
+						  PLUMA_SETTINGS_HIGHLIGHT_CURRENT_LINE);
 
 	val = ((state == PLUMA_TAB_STATE_NORMAL) &&
 	       (tab->priv->print_preview == NULL) &&
@@ -376,7 +387,7 @@ set_view_properties_according_to_state (PlumaTab      *tab,
 
 	val = ((state != PLUMA_TAB_STATE_LOADING) &&
 	       (state != PLUMA_TAB_STATE_CLOSING) &&
-	       (pluma_prefs_manager_get_highlight_current_line ()));
+	       hl_current_line);
 	gtk_source_view_set_highlight_current_line (GTK_SOURCE_VIEW (tab->priv->view), val);
 }
 
@@ -398,11 +409,15 @@ pluma_tab_set_state (PlumaTab      *tab,
 	    (state == PLUMA_TAB_STATE_SHOWING_PRINT_PREVIEW))
 	{
 		gtk_widget_hide (tab->priv->view_scrolled_window);
+		gtk_widget_hide (tab->priv->overlay);
 	}
 	else
 	{
 		if (tab->priv->print_preview == NULL)
+		{
 			gtk_widget_show (tab->priv->view_scrolled_window);
+			gtk_widget_show (tab->priv->overlay);
+		}
 	}
 
 	set_cursor_according_to_state (GTK_TEXT_VIEW (tab->priv->view),
@@ -883,7 +898,6 @@ document_loaded (PlumaDocument *document,
 		 const GError  *error,
 		 PlumaTab      *tab)
 {
-	GtkWidget *emsg;
 	GFile *location;
 	gchar *uri;
 
@@ -907,6 +921,8 @@ document_loaded (PlumaDocument *document,
 	if (error != NULL &&
 	    (error->domain != PLUMA_DOCUMENT_ERROR || error->code != PLUMA_DOCUMENT_ERROR_CONVERSION_FALLBACK))
 	{
+		GtkWidget *emsg;
+
 		if (tab->priv->state == PLUMA_TAB_STATE_LOADING)
 			pluma_tab_set_state (tab, PLUMA_TAB_STATE_LOADING_ERROR);
 		else
@@ -1481,12 +1497,18 @@ tab_mount_operation_factory (PlumaDocument *doc,
 static void
 pluma_tab_init (PlumaTab *tab)
 {
+	GtkWidget *hbox;
+	GtkWidget *map;
 	GtkWidget *sw;
 	PlumaDocument *doc;
 	PlumaLockdownMask lockdown;
+	gboolean auto_save;
+	gint auto_save_interval;
 
 	tab->priv = pluma_tab_get_instance_private (tab);
 
+	tab->priv->editor_settings = g_settings_new (PLUMA_SCHEMA_ID);
+
 	tab->priv->state = PLUMA_TAB_STATE_NORMAL;
 
 	tab->priv->not_editable = FALSE;
@@ -1507,14 +1529,19 @@ pluma_tab_init (PlumaTab *tab)
 					GTK_POLICY_AUTOMATIC);
 
 	/* Manage auto save data */
+	auto_save = g_settings_get_boolean (tab->priv->editor_settings,
+					    PLUMA_SETTINGS_AUTO_SAVE);
+	auto_save_interval = g_settings_get_uint (tab->priv->editor_settings, PLUMA_SETTINGS_AUTO_SAVE_INTERVAL);
+
 	lockdown = pluma_app_get_lockdown (pluma_app_get_default ());
-	tab->priv->auto_save = pluma_prefs_manager_get_auto_save () &&
+	tab->priv->auto_save = auto_save &&
 			       !(lockdown & PLUMA_LOCKDOWN_SAVE_TO_DISK);
 	tab->priv->auto_save = (tab->priv->auto_save != FALSE);
 
-	tab->priv->auto_save_interval = pluma_prefs_manager_get_auto_save_interval ();
+	tab->priv->auto_save_interval = auto_save_interval;
+	/*FIXME
 	if (tab->priv->auto_save_interval <= 0)
-		tab->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
+		tab->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;*/
 
 	/* Create the view */
 	doc = pluma_document_new ();
@@ -1529,12 +1556,46 @@ pluma_tab_init (PlumaTab *tab)
 	gtk_widget_show (tab->priv->view);
 	g_object_set_data (G_OBJECT (tab->priv->view), PLUMA_TAB_KEY, tab);
 
-	gtk_box_pack_end (GTK_BOX (tab), sw, TRUE, TRUE, 0);
 	gtk_container_add (GTK_CONTAINER (sw), tab->priv->view);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
 					     GTK_SHADOW_IN);
 	gtk_widget_show (sw);
 
+	/* Create the minimap overlay */
+	tab->priv->overlay = gtk_overlay_new ();
+	tab->priv->view_map_frame = gtk_frame_new (NULL);
+	map = gtk_source_map_new();
+
+	GtkCssProvider *provider = gtk_css_provider_new ();
+	gtk_css_provider_load_from_data (provider,
+					 "textview { font-family: Monospace; font-size: 1pt; }",
+					 -1,
+					 NULL);
+	gtk_style_context_add_provider (gtk_widget_get_style_context (map),
+					GTK_STYLE_PROVIDER (provider),
+					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	g_object_unref (provider);
+
+	gtk_source_map_set_view (GTK_SOURCE_MAP(map), GTK_SOURCE_VIEW(tab->priv->view));
+	gtk_container_add (GTK_CONTAINER(tab->priv->view_map_frame), map);
+	gtk_widget_show (tab->priv->view_map_frame);
+
+	/* Start packing */
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), sw, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), tab->priv->view_map_frame, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER(tab->priv->overlay), hbox);
+	gtk_box_pack_end (GTK_BOX (tab), tab->priv->overlay, TRUE, TRUE, 0);
+
+	gtk_widget_show (hbox);
+	gtk_widget_show (tab->priv->overlay);
+
+	g_settings_bind (tab->priv->editor_settings,
+			 PLUMA_SETTINGS_DISPLAY_OVERVIEW_MAP,
+			 tab->priv->view_map_frame,
+			 "visible",
+			 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_NO_SENSITIVITY);
+
 	g_signal_connect (doc,
 			  "notify::uri",
 			  G_CALLBACK (document_uri_notify_handler),
@@ -2617,7 +2678,7 @@ _pluma_tab_can_close (PlumaTab *tab)
 	    (ts == PLUMA_TAB_STATE_REVERTING)       ||
 	    (ts == PLUMA_TAB_STATE_REVERTING_ERROR) || /* CHECK: I'm not sure this is the right behavior for REVERTING ERROR */
 	    (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc))) ||
-	    (!g_settings_get_boolean (pluma_prefs_manager->settings, "show-save-confirmation")))
+	    (!g_settings_get_boolean (tab->priv->editor_settings, PLUMA_SETTINGS_SHOW_SAVE_CONFIRMATION)))
 		return TRUE;
 
 	/* Do not close tab with saving errors */
