@@ -5,6 +5,7 @@
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2002 Chema Celorio, Paolo Maggi
  * Copyright (C) 2003-2005 Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,19 +48,15 @@
 
 #include "pluma-utils.h"
 
+#include "pluma-settings.h"
 #include "pluma-document.h"
-#include "pluma-prefs-manager.h"
 #include "pluma-debug.h"
 
 /* For the workspace/viewport stuff */
-#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
-#endif
-
-#define STDIN_DELAY_MICROSECONDS 100000
 
 /**
  * pluma_utils_uris_has_file_scheme
@@ -83,11 +80,14 @@ pluma_utils_uri_has_file_scheme (const gchar *uri)
 gboolean
 pluma_utils_uri_has_writable_scheme (const gchar *uri)
 {
+	/* FIXME: Avoid making a new settings variable here. */
+	GSettings *settings;
 	GFile *gfile;
 	gchar *scheme;
 	GSList *writable_schemes;
 	gboolean res;
 
+	settings = g_settings_new (PLUMA_SCHEMA_ID);
 	gfile = g_file_new_for_uri (uri);
 	scheme = g_file_get_uri_scheme (gfile);
 
@@ -95,17 +95,17 @@ pluma_utils_uri_has_writable_scheme (const gchar *uri)
 
 	g_object_unref (gfile);
 
-	writable_schemes = pluma_prefs_manager_get_writable_vfs_schemes ();
+	writable_schemes = pluma_settings_get_writable_vfs_schemes (settings);
 
 	/* CHECK: should we use g_ascii_strcasecmp? - Paolo (Nov 6, 2005) */
 	res = (g_slist_find_custom (writable_schemes,
 				    scheme,
 				    (GCompareFunc)strcmp) != NULL);
 
-	g_slist_foreach (writable_schemes, (GFunc)g_free, NULL);
-	g_slist_free (writable_schemes);
+	g_slist_free_full (writable_schemes, g_free);
 
 	g_free (scheme);
+	g_object_unref (settings);
 
 	return res;
 }
@@ -847,42 +847,43 @@ pluma_utils_replace_home_dir_with_tilde (const gchar *uri)
 guint
 pluma_utils_get_current_workspace (GdkScreen *screen)
 {
-#ifdef GDK_WINDOWING_X11
-	GdkWindow *root_win;
-	GdkDisplay *display;
-	Atom type;
-	gint format;
-	gulong nitems;
-	gulong bytes_after;
-	guint *current_desktop;
-	gint err, result;
-	guint ret = 0;
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+	{
+		GdkWindow *root_win;
+		GdkDisplay *display;
+		Atom type;
+		gint format;
+		gulong nitems;
+		gulong bytes_after;
+		guint *current_desktop;
+		gint err, result;
+		guint ret = 0;
 
-	g_return_val_if_fail (GDK_IS_SCREEN (screen), 0);
+		g_return_val_if_fail (GDK_IS_SCREEN (screen), 0);
 
-	root_win = gdk_screen_get_root_window (screen);
-	display = gdk_screen_get_display (screen);
+		root_win = gdk_screen_get_root_window (screen);
+		display = gdk_screen_get_display (screen);
 
-	gdk_x11_display_error_trap_push (display);
-	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
-				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_CURRENT_DESKTOP"),
-				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
-				     &bytes_after, (gpointer) &current_desktop);
-	err = gdk_x11_display_error_trap_pop (display);
+		gdk_x11_display_error_trap_push (display);
+		result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID(root_win),
+					     gdk_x11_get_xatom_by_name_for_display (display, "_NET_CURRENT_DESKTOP"),
+					     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+					     &bytes_after, (gpointer) &current_desktop);
+		err = gdk_x11_display_error_trap_pop (display);
 
-	if (err != Success || result != Success)
+		if (err != Success || result != Success)
+			return ret;
+
+		if (type == XA_CARDINAL && format == 32 && nitems > 0)
+			ret = current_desktop[0];
+
+		XFree (current_desktop);
 		return ret;
-
-	if (type == XA_CARDINAL && format == 32 && nitems > 0)
-		ret = current_desktop[0];
-
-	XFree (current_desktop);
-	return ret;
-#else
-	/* FIXME: on mac etc proably there are native APIs
-	 * to get the current workspace etc */
-	return 0;
-#endif
+	}
+	else
+		/* FIXME: on mac etc proably there are native APIs
+		 * to get the current workspace etc */
+		return 0;
 }
 
 /**
@@ -897,43 +898,45 @@ pluma_utils_get_current_workspace (GdkScreen *screen)
 guint
 pluma_utils_get_window_workspace (GtkWindow *gtkwindow)
 {
-#ifdef GDK_WINDOWING_X11
-	GdkWindow *window;
-	GdkDisplay *display;
-	Atom type;
-	gint format;
-	gulong nitems;
-	gulong bytes_after;
-	guint *workspace;
-	gint err, result;
-	guint ret = PLUMA_ALL_WORKSPACES;
 
-	g_return_val_if_fail (GTK_IS_WINDOW (gtkwindow), 0);
-	g_return_val_if_fail (gtk_widget_get_realized (GTK_WIDGET (gtkwindow)), 0);
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+	{
+		GdkWindow *window;
+		GdkDisplay *display;
+		Atom type;
+		gint format;
+		gulong nitems;
+		gulong bytes_after;
+		guint *workspace;
+		gint err, result;
+		guint ret = PLUMA_ALL_WORKSPACES;
 
-	window = gtk_widget_get_window (GTK_WIDGET (gtkwindow));
-	display = gdk_window_get_display (window);
+		g_return_val_if_fail (GTK_IS_WINDOW (gtkwindow), 0);
+		g_return_val_if_fail (gtk_widget_get_realized (GTK_WIDGET (gtkwindow)), 0);
 
-	gdk_x11_display_error_trap_push (display);
-	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (window),
-				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_DESKTOP"),
-				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
-				     &bytes_after, (gpointer) &workspace);
-	err = gdk_x11_display_error_trap_pop (display);
+		window = gtk_widget_get_window (GTK_WIDGET (gtkwindow));
+		display = gdk_window_get_display (window);
 
-	if (err != Success || result != Success)
+		gdk_x11_display_error_trap_push (display);
+		result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (window),
+					     gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_DESKTOP"),
+					     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+					     &bytes_after, (gpointer) &workspace);
+		err = gdk_x11_display_error_trap_pop (display);
+
+		if (err != Success || result != Success)
+			return ret;
+
+		if (type == XA_CARDINAL && format == 32 && nitems > 0)
+			ret = workspace[0];
+
+		XFree (workspace);
 		return ret;
-
-	if (type == XA_CARDINAL && format == 32 && nitems > 0)
-		ret = workspace[0];
-
-	XFree (workspace);
-	return ret;
-#else
-	/* FIXME: on mac etc proably there are native APIs
-	 * to get the current workspace etc */
-	return 0;
-#endif
+	}
+	else
+		/* FIXME: on mac etc proably there are native APIs
+		 * to get the current workspace etc */
+		return 0;
 }
 
 /**
@@ -950,51 +953,54 @@ pluma_utils_get_current_viewport (GdkScreen    *screen,
 				  gint         *x,
 				  gint         *y)
 {
-#ifdef GDK_WINDOWING_X11
-	GdkWindow *root_win;
-	GdkDisplay *display;
-	Atom type;
-	gint format;
-	gulong nitems;
-	gulong bytes_after;
-	gulong *coordinates;
-	gint err, result;
-
-	g_return_if_fail (GDK_IS_SCREEN (screen));
-	g_return_if_fail (x != NULL && y != NULL);
-
-	/* Default values for the viewport origin */
-	*x = 0;
-	*y = 0;
-
-	root_win = gdk_screen_get_root_window (screen);
-	display = gdk_screen_get_display (screen);
-
-	gdk_x11_display_error_trap_push (display);
-	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
-				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_DESKTOP_VIEWPORT"),
-				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
-				     &bytes_after, (void*) &coordinates);
-	err = gdk_x11_display_error_trap_pop (display);
-
-	if (err != Success || result != Success)
-		return;
-
-	if (type != XA_CARDINAL || format != 32 || nitems < 2)
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
 	{
-		XFree (coordinates);
-		return;
-	}
+		GdkWindow *root_win;
+		GdkDisplay *display;
+		Atom type;
+		gint format;
+		gulong nitems;
+		gulong bytes_after;
+		gulong *coordinates;
+		gint err, result;
 
-	*x = coordinates[0];
-	*y = coordinates[1];
-	XFree (coordinates);
-#else
+		g_return_if_fail (GDK_IS_SCREEN (screen));
+		g_return_if_fail (x != NULL && y != NULL);
+
+		/* Default values for the viewport origin */
+		*x = 0;
+		*y = 0;
+
+		root_win = gdk_screen_get_root_window (screen);
+		display = gdk_screen_get_display (screen);
+
+		gdk_x11_display_error_trap_push (display);
+		result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
+					     gdk_x11_get_xatom_by_name_for_display (display, "_NET_DESKTOP_VIEWPORT"),
+					     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+					     &bytes_after, (void*) &coordinates);
+		err = gdk_x11_display_error_trap_pop (display);
+
+		if (err != Success || result != Success)
+			return;
+
+		if (type != XA_CARDINAL || format != 32 || nitems < 2)
+		{
+			XFree (coordinates);
+			return;
+		}
+
+		*x = coordinates[0];
+		*y = coordinates[1];
+		XFree (coordinates);
+	}
+	else
 	/* FIXME: on mac etc proably there are native APIs
 	 * to get the current workspace etc */
-	*x = 0;
-	*y = 0;
-#endif
+	{
+		*x = 0;
+		*y = 0;
+	}
 }
 
 static gboolean
@@ -1415,8 +1421,8 @@ null_ptr (gchar **ptr)
  * @scheme: (allow-none): return value pointer for the uri's
  * scheme (e.g. http, sftp, ...), or %NULL
  * @user: (allow-none): return value pointer for the uri user info, or %NULL
- * @port: (allow-none): return value pointer for the uri port, or %NULL
  * @host: (allow-none): return value pointer for the uri host, or %NULL
+ * @port: (allow-none): return value pointer for the uri port, or %NULL
  * @path: (allow-none): return value pointer for the uri path, or %NULL
  *
  * Parse and break an uri apart in its individual components like the uri
@@ -1574,7 +1580,7 @@ pluma_gtk_text_iter_regex_search (const GtkTextIter *iter,
 	gboolean found;
 
 	match_string = "";
-	compile_flags = 0;
+	compile_flags = G_REGEX_OPTIMIZE | G_REGEX_MULTILINE;
 
 	if ((flags & GTK_TEXT_SEARCH_CASE_INSENSITIVE) != 0)
 		compile_flags |= G_REGEX_CASELESS;
@@ -1664,32 +1670,3 @@ free_resources:
 	g_regex_unref (regex);
 	return found;
 }
-
-GtkWidget *
-pluma_image_menu_item_new_from_pixbuf (GdkPixbuf   *icon_pixbuf,
-				       const gchar *label_name)
-{
-	gchar *concat;
-	GtkWidget *icon;
-	GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-
-	if (icon_pixbuf)
-		icon = gtk_image_new_from_pixbuf (icon_pixbuf);
-	else
-		icon = gtk_image_new ();
-
-	concat = g_strconcat (label_name, "     ", NULL);
-
-	GtkWidget *label_menu = gtk_label_new (concat);
-	GtkWidget *menuitem = gtk_menu_item_new ();
-
-	gtk_container_add (GTK_CONTAINER (box), icon);
-	gtk_container_add (GTK_CONTAINER (box), label_menu);
-
-	gtk_container_add (GTK_CONTAINER (menuitem), box);
-	gtk_widget_show_all (menuitem);
-
-	g_free (concat);
-
-	return menuitem;
-}
