@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,10 +53,10 @@
 #include "pluma-dirs.h"
 #include "pluma-encodings.h"
 #include "pluma-plugins-engine.h"
-#include "pluma-prefs-manager-app.h"
 #include "pluma-session.h"
 #include "pluma-utils.h"
 #include "pluma-window.h"
+#include "pluma-settings.h"
 
 #include "eggsmclient.h"
 #include "eggdesktopfile.h"
@@ -83,7 +84,7 @@ show_version_and_quit (void)
 {
 	g_print ("%s - Version %s\n", g_get_application_name (), VERSION);
 
-	exit (0);
+	exit (EXIT_SUCCESS);
 }
 
 static void
@@ -99,7 +100,7 @@ list_encodings_and_quit (void)
 		++i;
 	}
 
-	exit (0);
+	exit (EXIT_SUCCESS);
 }
 
 static const GOptionEntry options [] =
@@ -128,8 +129,7 @@ static const GOptionEntry options [] =
 static void
 free_command_line_data (void)
 {
-	g_slist_foreach (file_list, (GFunc) g_object_unref, NULL);
-	g_slist_free (file_list);
+	g_slist_free_full (file_list, g_object_unref);
 	file_list = NULL;
 
 	g_strfreev (remaining_args);
@@ -379,13 +379,16 @@ on_message_received (const char *message,
 	if (!gtk_widget_get_realized (GTK_WIDGET (window)))
 		gtk_widget_realize (GTK_WIDGET (window));
 
-	if (startup_timestamp <= 0)
-		startup_timestamp = gdk_x11_get_server_time (gtk_widget_get_window (GTK_WIDGET (window)));
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+	{
+		if (startup_timestamp <= 0)
+			startup_timestamp = gdk_x11_get_server_time (gtk_widget_get_window (GTK_WIDGET (window)));
 
-	gdk_x11_window_set_user_time (gtk_widget_get_window (GTK_WIDGET (window)),
-				      startup_timestamp);
-
-	gtk_window_present (GTK_WINDOW (window));
+		gdk_x11_window_set_user_time (gtk_widget_get_window (GTK_WIDGET (window)), startup_timestamp);
+		gtk_window_present (GTK_WINDOW (window));
+	}
+	else
+		gtk_window_present_with_time (GTK_WINDOW (window), GPOINTER_TO_UINT (data));
 
  out:
 	g_strfreev (commands);
@@ -422,7 +425,11 @@ send_bacon_message (void)
 	display = gdk_screen_get_display (screen);
 
 	display_name = gdk_display_get_name (display);
-	screen_number = gdk_x11_screen_get_screen_number (screen);
+
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+		screen_number = gdk_x11_screen_get_screen_number (screen);
+	else
+		screen_number = 0;
 
 	pluma_debug_message (DEBUG_APP, "Display: %s", display_name);
 	pluma_debug_message (DEBUG_APP, "Screen: %d", screen_number);
@@ -500,9 +507,6 @@ main (int argc, char *argv[])
 	PlumaApp *app;
 	gboolean restored = FALSE;
 	GError *error = NULL;
-	gchar *dir;
-	gchar *icon_dir;
-
 
 	/* Setup debugging */
 	pluma_debug_init ();
@@ -510,14 +514,10 @@ main (int argc, char *argv[])
 
 	setlocale (LC_ALL, "");
 
-	dir = pluma_dirs_get_pluma_locale_dir ();
-	bindtextdomain (GETTEXT_PACKAGE, dir);
-	g_free (dir);
+	bindtextdomain (GETTEXT_PACKAGE, PLUMA_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gdk_set_allowed_backends ("x11");
-
 	startup_timestamp = get_startup_timestamp();
 
 	/* Setup command line options */
@@ -564,7 +564,7 @@ main (int argc, char *argv[])
 
 			bacon_message_connection_free (connection);
 
-			exit (0);
+			exit (EXIT_SUCCESS);
 		}
 		else
 		{
@@ -581,24 +581,12 @@ main (int argc, char *argv[])
 	}
 
 	pluma_debug_message (DEBUG_APP, "Set icon");
-
-	dir = pluma_dirs_get_pluma_data_dir ();
-	icon_dir = g_build_filename (dir,
-				     "icons",
-				     NULL);
-	g_free (dir);
-
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-					   icon_dir);
-	g_free (icon_dir);
+					   PLUMA_DATADIR "/icons");
 
 	/* Set the associated .desktop file */
 	egg_set_desktop_file (DATADIR "/applications/pluma.desktop");
 
-	/* Load user preferences */
-	pluma_debug_message (DEBUG_APP, "Init prefs manager");
-	pluma_prefs_manager_app_init ();
-
 	/* Init plugins engine */
 	pluma_debug_message (DEBUG_APP, "Init plugins");
 	engine = pluma_plugins_engine_get_default ();
@@ -620,6 +608,7 @@ main (int argc, char *argv[])
 
 		pluma_debug_message (DEBUG_APP, "Create main window");
 		window = pluma_app_create_window (app, NULL);
+		gtk_widget_set_size_request (GTK_WIDGET (window), 250, 250);
 
 		if (file_list != NULL)
 		{
@@ -656,12 +645,13 @@ main (int argc, char *argv[])
 	 * finalize it properly.
 	 */
 	g_object_unref (engine);
-	pluma_prefs_manager_app_shutdown ();
+
+	pluma_settings_unref_singleton ();
 
 #ifndef ENABLE_GVFS_METADATA
 	pluma_metadata_manager_shutdown ();
 #endif
 
-	return 0;
+	return EXIT_SUCCESS;
 }
 
